import { CSSRules } from "@microsoft/fast-jss-manager";
import { DesignSystem } from "../design-system";
/**
 * Shadow config
 */
export interface ShadowConfig {
    blurMultiplier: number;
    blurBase?: number;
    opacity: number;
    xOffsetMultiplier: number;
    yOffsetMultiplier: number;
}
/**
 * The MSFT elevation values
 */
export declare enum ElevationMultiplier {
    e1 = 1,
    e2 = 2,
    e3 = 3,
    e4 = 4,
    e5 = 6,
    e6 = 8,
    e7 = 9,
    e8 = 12,
    e9 = 16,
    e10 = 24,
    e11 = 32,
    e12 = 40,
    e13 = 48,
    e14 = 64,
    e15 = 80,
    e16 = 96,
    e17 = 192
}
/**
 * Ambient shadow config
 */
export declare const ambientShadowConfig: ShadowConfig;
/**
 * Directional shadow config
 */
export declare const directionalShadowConfig: ShadowConfig;
/**
 * Generate Elevation Shadow
 * Generates a string representing a box shadow value
 */
export declare function elevationShadow(elevationValue: number, color: string, shadowConfig: ShadowConfig): (config: DesignSystem) => string;
/**
 * Apply elevation shadow treatment to a component.
 *
 * @param elevationValue The number of pixels of depth or an ElevationMultiplier value.
 */
export declare function applyElevation(elevationValue: ElevationMultiplier | number): CSSRules<DesignSystem>;
/**
 * Apply elevation
 * Used to apply elevation shadow treatment to a component
 *
 * @deprecated Use applyElevation.
 */
export declare function elevation(elevationValue: ElevationMultiplier | number, color?: string): (config: DesignSystem) => CSSRules<DesignSystem>;
