import { CSSRules } from "@microsoft/fast-jss-manager";
import { DesignSystem, DesignSystemResolver } from "../design-system";
/**
 * The type ramp item config
 */
export interface TypeRampItemConfig {
    fontSize: number;
    lineHeight: number;
}
/**
 * The type ramp item type
 */
export declare type TypeRampItem = TypeRampItemConfig;
/**
 * The type ramp which covers all type configurations used
 * in typographic elements
 */
export interface TypeRamp {
    t1: TypeRampItem;
    t2: TypeRampItem;
    t3: TypeRampItem;
    t4: TypeRampItem;
    t5: TypeRampItem;
    t6: TypeRampItem;
    t7: TypeRampItem;
    t8: TypeRampItem;
    t9: TypeRampItem;
}
/**
 * The type ramp configuration
 */
export declare const typeRamp: TypeRamp;
/**
 * Retrieves the font-size from a TypeRamp ID
 */
export declare function getFontSize(key: keyof TypeRamp): number;
/**
 * Retrieves the line-height from a TypeRamp ID
 */
export declare function getLineHeight(key: keyof TypeRamp): number;
/**
 * Retrieves the formatted font-size from a TypeRamp ID
 */
export declare function applyFontSize(key: keyof TypeRamp): string;
/**
 * Retrieves the formatted line-height from a TypeRamp ID
 */
export declare function applyLineHeight(key: keyof TypeRamp): string;
/**
 * Retrieves the font-size from a TypeRamp ID, scaled with the design-system density
 */
export declare function getScaledFontSize(key: keyof TypeRamp): DesignSystemResolver<number>;
/**
 * Retrieves the line-height from a TypeRamp ID, scaled with the design-system density
 */
export declare function getScaledLineHeight(key: keyof TypeRamp): DesignSystemResolver<number>;
/**
 * Retrieves the formatted font-size from a TypeRamp ID, scaled with the design-system density
 */
export declare function applyScaledFontSize(key: keyof TypeRamp): DesignSystemResolver<string>;
/**
 * Retrieves the formatted line-height from a TypeRamp ID, scaled with the design-system density
 */
export declare function applyScaledLineHeight(key: keyof TypeRamp): DesignSystemResolver<string>;
declare function applyTypeRampFactory(fontSizeGetter: (key: keyof TypeRamp) => string | DesignSystemResolver<string>, lineHeightGetter: (key: keyof TypeRamp) => string | DesignSystemResolver<string>): (key: keyof TypeRamp) => CSSRules<DesignSystem>;
/**
 * Applies font size and line-height properties from the typeramp
 */
export declare const applyTypeRamp: ReturnType<typeof applyTypeRampFactory>;
/**
 * Applies font size and line-height from the type ramp, scaled with design system density
 */
export declare const applyScaledTypeRamp: ReturnType<typeof applyTypeRampFactory>;
/**
 * Takes a param of type ramp key (string) and returns a type ramp configuration
 * @deprecated - please use applyTypeRamp
 */
export declare const applyTypeRampConfig: typeof applyTypeRamp;
export {};
